


import random

class battleship:
    def __init__(self, shipsize):
        self.shipsize = shipsize
        self.column = [1, 2, 3, 4, 5, 6, 7, 8, 9]
        self.row = ["a", "b", "c", "d"]
        self.column_length = len(self.column)
        self.row_length = len(self.row)

    def shipplace(self, row_choose, position):
        new_position = []
        for pos in position:
            x = row_choose + str(pos)
            new_position.append(x)
        return new_position

    def putship(self):
        column_choose = random.choice(self.column)
        row_choose = random.choice(self.row)
        position = []
        if column_choose + self.shipsize < self.column_length:
            position = range(column_choose, column_choose + self.shipsize, 1)
        else:
            position = range(column_choose, column_choose - self.shipsize, -1)
        self.place = self.shipplace(row_choose, position)
    
    def guessship(self):
        turns = 10
        hit = 0
        while turns > 0:
            print("the ship can be located anywhere from rows - a, b, c, d and columns - 1,2,3,4,5,6,7,8,9")
            guess = input("type place: ")
            if guess in self.place:
                print("ITS A HIT!!")
                hit -= 1
                print("come on  you should only hit the ship " + hit + " times!")
                if hit == 0:
                    print("You sunk the ship")
            else:
                print("ITS A MISS")
            turns -= 1


if __name__ == '__main__':
    game1 = battleship(3)
    game1.putship()
    game1.guessship()




from setuptools import setup


__project__ = "ex_battleship"
__version__ = "0.0.2"
__description__ = "ex_battleship is a free package to play the game Battleship, this is version 1, it may be different, you have to guess where the one and only ship (computer's ship) is. After you guess the first one, and it'll be easy!"
__packages__ = ["ex_battleship"]
__author__ = "Rigved Aneesh"
__author_email__ = "rigved.bob@gmail.com"
__classifiers__ = [
    "Development Status :: 3 - Alpha",
    "Intended Audience :: Education",
    "Programming Language :: Python :: 3",
]
__keywords__ = ["battleship", "game"]
setup(
    name = __project__,
    version = __version__,
    description = __description__,
    packages = __packages__,
    author = __author__,
    author_email = __author_email__,
    classifiers = __classifiers__,
    keywords = __keywords__
)


